/**************************************************************************************
Author:			David Szybala
Program:		Materials_Brazil2_Advanced.ms
Date:			11/18/09
Description:	This script allows the user to affect muliple brazil2 materials simultaneously.
***************************************************************************************/

try (destroyDialog brazil2Rollout) catch()

(--put script into local scope
	global brazil2Rollout
	local brazil2Materials = #()
	local brazil2IniFile = getDir #plugcfg + "\\Brazil2Mat.ini"
	local brazil2RolloutPos
	
	/***************************************************************************************/
	fn Sort_By_Name elementOne elementTwo =
	(
		case of
		(
			(elementOne.name < elementTwo.name): -1
			(elementOne.name > elementTwo.name): 1
			default: 0
		)--end case
	)--end fn
	
	/***************************************************************************************/
	fn Refresh_Material_List =
	(
		brazil2Materials = #()
		
		for currentMat in (getClassInstances Brazil2_Advanced_Material) do append brazil2Materials currentMat
		
		local brazil2MatNames = #()
		local enableButtons = false
		
		if brazil2Materials.count > 0 do
		(
			qsort brazil2Materials Sort_By_Name
			for current in brazil2Materials do append brazil2MatNames current.name
			brazil2Rollout.brazil2List.items = brazil2MatNames
			enableButtons = true
		)--end if
		
		brazil2Rollout.totalLabel.text = ("Total: " + (brazil2Materials.count as string))
		
		brazil2Rollout.spinnerDropDown.enabled = brazil2Rollout.spinnerSelector.enabled = \
		brazil2Rollout.checkDropDown.enabled = brazil2Rollout.checkON.enabled = brazil2Rollout.checkOFF.enabled = \
		brazil2Rollout.colorDropDown.enabled = brazil2Rollout.colorSelector.enabled = \
		brazil2Rollout.mapDropDown.enabled = brazil2Rollout.mapSelector.enabled = \
		brazil2Rollout.mapAmtDropDown.enabled = brazil2Rollout.mapAmtSelector.enabled = \
		brazil2Rollout.mapCheckDropDown.enabled = brazil2Rollout.mapCheckON.enabled = brazil2Rollout.mapCheckOFF.enabled = enableButtons
	)--end fn
	
	/***************************************************************************************/
	fn Set_Value currentMat theValue =
	(
		case brazil2Rollout.spinnerDropDown.selection of
		(
			(1):(
					case of
					(
						(isProperty currentMat "Brazil_Default"):currentMat.Brazil_Default.Ka = theValue
						(isProperty currentMat "Car_Paint"):currentMat.Car_Paint.Ka = theValue
						(isProperty currentMat "Ghost"):currentMat.Ghost.Ka = theValue
						(isProperty currentMat "Glow_Worm"):currentMat.Glow_Worm.Ka = theValue
						(isProperty currentMat "Lambert"):currentMat.Lambert.Ka = theValue
						(isProperty currentMat "Oren_Nayar"):currentMat.Oren_Nayar.Ka = theValue
						(isProperty currentMat "Skin"):currentMat.Skin.Ka = theValue
						(isProperty currentMat "Velvet"):currentMat.Velvet.Ka = theValue
						(isProperty currentMat "Wax"):currentMat.Wax.Ka = theValue
					)--end case
				)--end case 1
			(2):(
					case of
					(
						(isProperty currentMat "Brazil_Default"):currentMat.Brazil_Default.Kd = theValue
						(isProperty currentMat "Ghost"):currentMat.Ghost.Kd = theValue
						(isProperty currentMat "Glow_Worm"):currentMat.Glow_Worm.Kd = theValue
						(isProperty currentMat "Lambert"):currentMat.Lambert.Kd = theValue
						(isProperty currentMat "Oren_Nayar"):currentMat.Oren_Nayar.Kd = theValue
						(isProperty currentMat "Skin"):currentMat.Skin.Kd = theValue
						(isProperty currentMat "Velvet"):currentMat.Velvet.Kd = theValue
						(isProperty currentMat "Wax"):currentMat.Wax.Kd = theValue
					)--end case
				)--end case 2
			(3):(
					case of
					(
						(isProperty currentMat "Brazil_Default"):currentMat.Brazil_Default.Kl = theValue
						(isProperty currentMat "Oren_Nayar"):currentMat.Oren_Nayar.Kl = theValue
						(isProperty currentMat "Velvet"):currentMat.Velvet.Kl = theValue
						(isProperty currentMat "Wax"):currentMat.Wax.Kl = theValue
					)--end case
				)--end case 3
			(4):(
					case of
					(
						(isProperty currentMat "Brazil_Default"):currentMat.Brazil_Default.ior_amount = theValue
						(isProperty currentMat "Car_Paint"):currentMat.Car_Paint.reflect_ior = theValue
						(isProperty currentMat "Oren_Nayar"):currentMat.Oren_Nayar.ior_amount = theValue
						(isProperty currentMat "Velvet"):currentMat.Velvet.ior_amount = theValue
						(isProperty currentMat "Wax"):currentMat.Wax.ior_amount = theValue
					)--end case
				)--end case 4
			(5):(
					case of
					(
						(isProperty currentMat "Brazil_Default"):currentMat.Brazil_Default.Kr = theValue
						(isProperty currentMat "Oren_Nayar"):currentMat.Oren_Nayar.Kr = theValue
						(isProperty currentMat "Velvet"):currentMat.Velvet.Kr = theValue
						(isProperty currentMat "Wax"):currentMat.Wax.Kr = theValue
					)--end case
				)--end case 5
			(6):currentMat.Advanced_Reflection_Params.refl_glossiness = theValue
			(7):currentMat.Advanced_Reflection_Params.refl_gloss_sample_rate = theValue as integer
			(8):currentMat.Advanced_Reflection_Params.refl_gloss_max_error = theValue
			(9):currentMat.Advanced_Reflection_Params.refl_decay_start = theValue
			(10):currentMat.Advanced_Reflection_Params.refl_decay_end = theValue
			(11):currentMat.Advanced_Reflection_Params.refl_decay_env_level = theValue
			(12):currentMat.Advanced_Refraction_Params.refr_glossiness = theValue
			(13):currentMat.Advanced_Reflection_Params.refl_gloss_sample_rate = theValue as integer
			(14):currentMat.Advanced_Reflection_Params.refl_gloss_max_error = theValue
			(15):currentMat.Advanced_Refraction_Params.refr_absorptivity_red = theValue
			(16):currentMat.Advanced_Refraction_Params.refr_absorptivity_green = theValue
			(17):currentMat.Advanced_Refraction_Params.refr_absorptivity_blue = theValue
			(18):currentMat.Advanced_Refraction_Params.refr_absorption_start = theValue
			(19):currentMat.Advanced_Refraction_Params.refr_absorption_end = theValue
			(20):currentMat.Advanced_Refraction_Params.refr_disperse_variance = theValue
			(21):currentMat.Advanced_Refraction_Params.refr_spectral_steps = theValue as integer
			(22):(
					if (isProperty currentMat "Phong_Highlight") do currentMat.Phong_Highlight.specular_level = theValue
					if (isProperty currentMat "Blinn_Highlight") do currentMat.Blinn_Highlight.specular_level = theValue
				 )--end case 22
			(23):(
					if (isProperty currentMat "Phong_Highlight") do currentMat.Phong_Highlight.glossiness = theValue
					if (isProperty currentMat "Blinn_Highlight") do currentMat.Blinn_Highlight.glossiness = theValue
				 )--end case 23
			(24):(
					if (isProperty currentMat "Phong_Highlight") do currentMat.Phong_Highlight.soften = theValue
					if (isProperty currentMat "Blinn_Highlight") do currentMat.Blinn_Highlight.soften = theValue
				 )--end case 24
			(25):(
					if (isProperty currentMat "Phong_Highlight") do currentMat.Phong_Highlight.gain = theValue
					if (isProperty currentMat "Blinn_Highlight") do currentMat.Blinn_Highlight.gain = theValue
				 )--end case 25
			(26):if (isProperty currentMat "Blinn_Highlight") do currentMat.Blinn_Highlight.anisotropy = theValue
		)--end case
	)--end fn
	
	/***************************************************************************************/
	fn Set_Boolean currentMat theState =
	(
		case brazil2Rollout.checkDropDown.selection of
		(
			(1):currentMat.bmtl_twosided_on = theState
			(2):currentMat.bmtl_facemap_on = theState
			(3):currentMat.bmtl_faceted_on = theState
			(4):currentMat.bmtl_transp_shadows_on = theState
			(5):currentMat.Advanced_Reflection_Params.refl_gloss_on = theState
			(6):currentMat.Advanced_Reflection_Params.refl_gloss_adapt_on = theState
			(7):currentMat.Advanced_Reflection_Params.refl_decay_on = theState
			(8):currentMat.Advanced_Reflection_Params.refl_prevent_intern_refl_on = theState
			(9):currentMat.Advanced_Reflection_Params.refl_gen_caustics_on = theState
			(10):currentMat.Advanced_Refraction_Params.refr_gloss_on = theState
			(11):currentMat.Advanced_Refraction_Params.refr_gloss_adapt_on = theState
			(12):currentMat.Advanced_Refraction_Params.refr_absorption_on = theState
			(13):currentMat.Advanced_Refraction_Params.refr_disperse_on = theState
			(14):currentMat.Advanced_Refraction_Params.refr_gen_caustics_on = theState
			(15):(
					if (isProperty currentMat "Phong_Highlight") do currentMat.Phong_Highlight.area_spec_on = theState
					if (isProperty currentMat "Blinn_Highlight") do currentMat.Blinn_Highlight.area_spec_on = theState
				 )--end case 15
			(16):currentMat.bmtl_use_Os_as_Tx_on = theState
		)--end case
	)--end fn
	
	/***************************************************************************************/
	fn Set_Color currentMat theColor =
	(
		case brazil2Rollout.colorDropDown.selection of
		(
			(1):(
					case of
					(
						(isProperty currentMat "Brazil_Default"):currentMat.Brazil_Default.ambient_color = theColor
						(isProperty currentMat "Ghost"):currentMat.Ghost.ambient_color = theColor
						(isProperty currentMat "Glow_Worm"):currentMat.Glow_Worm.ambient_color = theColor
						(isProperty currentMat "Lambert"):currentMat.Lambert.ambient_color = theColor
						(isProperty currentMat "Oren_Nayar"):currentMat.Oren_Nayar.ambient_color = theColor
						(isProperty currentMat "Skin"):currentMat.Skin.ambient_color = theColor
						(isProperty currentMat "Velvet"):currentMat.Velvet.ambient_color = theColor
						(isProperty currentMat "Wax"):currentMat.Wax.ambient_color = theColor
					)--end case
				)--end case 1
			(2):currentMat.bmtl_Cs_color = theColor
			(3):(
					case of
					(
						(isProperty currentMat "Brazil_Default"):currentMat.Brazil_Default.luminosity_color = theColor
						(isProperty currentMat "Oren_Nayar"):currentMat.Oren_Nayar.luminosity_color = theColor
						(isProperty currentMat "Velvet"):currentMat.Velvet.luminosity_color = theColor
						(isProperty currentMat "Wax"):currentMat.Wax.luminosity_color = theColor
					)--end case
				)--end case 3
			(4):currentMat.bmtl_Os_color = theColor
			(5):(
					case of
					(
						(isProperty currentMat "Brazil_Default"):currentMat.Brazil_Default.reflect_color = theColor
						(isProperty currentMat "Car_Paint"):currentMat.Car_Paint.reflect_color = theColor
						(isProperty currentMat "Oren_Nayar"):currentMat.Oren_Nayar.reflect_color = theColor
						(isProperty currentMat "Velvet"):currentMat.Velvet.reflect_color = theColor
						(isProperty currentMat "Wax"):currentMat.Wax.reflect_color = theColor
					)--end case
				)--end case 5
			(6):(
					case of
					(
						(isProperty currentMat "Brazil_Default"):currentMat.Brazil_Default.reflect_tint = theColor
						(isProperty currentMat "Oren_Nayar"):currentMat.Oren_Nayar.reflect_tint = theColor
					)--end case
				)--end case 6
			(7):currentMat.Advanced_Reflection_Params.refl_decay_color = theColor
			(8):currentMat.Advanced_Refraction_Params.refr_absorption_color = theColor
			(9):(
					if (isProperty currentMat "Phong_Highlight") do currentMat.Phong_Highlight.specular_color = theColor
					if (isProperty currentMat "Blinn_Highlight") do currentMat.Blinn_Highlight.specular_color = theColor
				 )--end case 9
			(10):currentMat.bmtl_xtra_light_color = theColor
		)--end case
	)--end fn
	
	/***************************************************************************************/
	fn Set_Map currentMat theMap =
	(
		case brazil2Rollout.mapDropDown.selection of
		(
			(1):currentMat.Advanced_Reflection_Params.refl_focus_map = theMap
			(2):currentMat.Advanced_Refraction_Params.refr_focus_map = theMap
			(3):currentMat.Advanced_Refraction_Params.refr_absorption_map = theMap
			(4):currentMat.bmtl_Cs_map = theMap
			(5):currentMat.bmtl_Os_map = theMap
			(6):currentMat.bmtl_xtra_light_map = theMap
			(7):currentMat.bmtl_Ld_map = theMap
			(8):currentMat.bmtl_bump_map = theMap
			(9):currentMat.bmtl_disp_map = theMap
			(10):currentMat.bmtl_env_map = theMap
			(11):currentMat.TexmapMgr.Ambient.tms_map = theMap
			(12):currentMat.TexmapMgr.Luminosity.tms_map = theMap
			(13):currentMat.TexmapMgr.Ka.tms_map = theMap
			(14):currentMat.TexmapMgr.Kd.tms_map = theMap
			(15):currentMat.TexmapMgr.Kl.tms_map = theMap
			(16):currentMat.TexmapMgr.Reflectivity.tms_map = theMap
			(17):currentMat.TexmapMgr.Reflection_Tint.tms_map = theMap
			(18):currentMat.TexmapMgr.Kr.tms_map = theMap
			(19):currentMat.TexmapMgr.IOR.tms_map = theMap
			(20):currentMat.TexmapMgr.Specular_Color.tms_map = theMap
			(21):currentMat.TexmapMgr.Spec__Level.tms_map = theMap
			(22):currentMat.TexmapMgr.Spec__Gloss.tms_map = theMap
			(23):currentMat.TexmapMgr.Soften.tms_map = theMap
			(24):currentMat.TexmapMgr.Gain.tms_map = theMap
		)--end case
	)--end fn
	
	/***************************************************************************************/
	fn Set_Map_Amount currentMat theValue =
	(
		case brazil2Rollout.mapAmtDropDown.selection of
		(
			(1):currentMat.Advanced_Reflection_Params.refl_focus_map_amt = theValue / 100.0
			(2):currentMat.Advanced_Refraction_Params.refr_focus_map_amt = theValue / 100.0
			(3):currentMat.Advanced_Refraction_Params.refr_absorption_map_amt = theValue / 100.0
			(4):currentMat.bmtl_Cs_map_amt = theValue / 100.0
			(5):currentMat.bmtl_Os_map_amt = theValue / 100.0
			(6):currentMat.bmtl_xtra_light_map_amt = theValue / 100.0
			(7):currentMat.bmtl_Ld_map_amt = theValue / 100.0
			(8):currentMat.bmtl_bump_map_amt = theValue / 100.0
			(9):currentMat.bmtl_disp_map_amt = theValue / 100.0
			(10):currentMat.TexmapMgr.Ambient.tms_map_amt = theValue / 100.0
			(11):currentMat.TexmapMgr.Luminosity.tms_map_amt = theValue / 100.0
			(12):currentMat.TexmapMgr.Ka.tms_map_amt = theValue / 100.0
			(13):currentMat.TexmapMgr.Kd.tms_map_amt = theValue / 100.0
			(14):currentMat.TexmapMgr.Kl.tms_map_amt = theValue / 100.0
			(15):currentMat.TexmapMgr.Reflectivity.tms_map_amt = theValue / 100.0
			(16):currentMat.TexmapMgr.Reflection_Tint.tms_map_amt = theValue / 100.0
			(17):currentMat.TexmapMgr.Kr.tms_map_amt = theValue / 100.0
			(18):currentMat.TexmapMgr.IOR.tms_map_amt = theValue / 100.0
			(19):currentMat.TexmapMgr.Specular_Color.tms_map_amt = theValue / 100.0
			(20):currentMat.TexmapMgr.Spec__Level.tms_map_amt = theValue / 100.0
			(21):currentMat.TexmapMgr.Spec__Gloss.tms_map_amt = theValue / 100.0
			(22):currentMat.TexmapMgr.Soften.tms_map_amt = theValue / 100.0
			(23):currentMat.TexmapMgr.Gain.tms_map_amt = theValue / 100.0
		)--end case
	)--end fn
	
	/***************************************************************************************/
	fn Set_Map_Boolean currentMat theState =
	(
		case brazil2Rollout.mapCheckDropDown.selection of
		(
			(1):currentMat.Advanced_Reflection_Params.refl_focus_map_on = theState
			(2):currentMat.Advanced_Refraction_Params.refr_focus_map_on = theState
			(3):currentMat.Advanced_Refraction_Params.refr_absorption_map_on = theState
			(4):currentMat.bmtl_Cs_map_on = theState
			(5):currentMat.bmtl_Os_map_on = theState
			(6):currentMat.bmtl_xtra_light_map_on = theState
			(7):currentMat.bmtl_Ld_map_on = theState
			(8):currentMat.bmtl_bump_map_on = theState
			(9):currentMat.bmtl_disp_map_on = theState
			(10):currentMat.bmtl_env_map_on = theState
			(11):currentMat.TexmapMgr.Ambient.tms_map_on = theState
			(12):currentMat.TexmapMgr.Luminosity.tms_map_on = theState
			(13):currentMat.TexmapMgr.Ka.tms_map_on = theState
			(14):currentMat.TexmapMgr.Kd.tms_map_on = theState
			(15):currentMat.TexmapMgr.Kl.tms_map_on = theState
			(16):currentMat.TexmapMgr.Reflectivity.tms_map_on = theState
			(17):currentMat.TexmapMgr.Reflection_Tint.tms_map_on = theState
			(18):currentMat.TexmapMgr.Kr.tms_map_on = theState
			(19):currentMat.TexmapMgr.IOR.tms_map_on = theState
			(20):currentMat.TexmapMgr.Specular_Color.tms_map_on = theState
			(21):currentMat.TexmapMgr.Spec__Level.tms_map_on = theState
			(22):currentMat.TexmapMgr.Spec__Gloss.tms_map_on = theState
			(23):currentMat.TexmapMgr.Soften.tms_map_on = theState
			(24):currentMat.TexmapMgr.Gain.tms_map_on = theState
		)--end case
	)--end fn
	
	/***************************************************************************************/
	fn Set_Function currentMat currentValue functionIndex =
	(
		case functionIndex of
		(
			(1):Set_Value currentMat currentValue
			(2):Set_Boolean currentMat currentValue
			(3):Set_Color currentMat currentValue
			(4):Set_Map currentMat currentValue
			(5):Set_Map_Amount currentMat currentValue
			(6):Set_Map_Boolean currentMat currentValue
		)--end case
	)--end fn
	
	/***************************************************************************************/
	fn Set_Material_Main currentValue functionIndex =
	(
		case brazil2Rollout.modeRadio.state of
		(
			(1): for index in (brazil2Rollout.brazil2List.selection as array) do Set_Function brazil2Materials[index] currentValue functionIndex
			(2): for currentMat in brazil2Materials do Set_Function currentMat currentValue functionIndex
			(3): for currentObj in selection do
				 (
					 if currentObj.material != undefined do
					 (
						 if (classOf currentObj.material) == Brazil2_Advanced_Material do Set_Function currentObj.material currentValue functionIndex
					 )--end if
				 )--end for
		)--end case
	)--end fn
	
	/***************************************************************************************/
	rollout brazil2Rollout "Brazil2 Advanced"
	(
		label totalLabel "Total: " pos:[5,5] width:150 height:15
		button updateButton "Update" pos:[150,3] width:50 height:15
		MultiListBox brazil2List "" pos:[5,20] width:195 height:17
		
		radiobuttons modeRadio "" pos:[5,250] labels:#("List Select","All Brazil2","Scene Select") columns:2
		
		dropDownList spinnerDropDown "" pos:[5,285] width:140 height:20 enabled:false
		spinner spinnerSelector "" pos:[150,287] range:[0,100,1] type:#float scale:0.1 width:50 height:16 enabled:false
		
		dropDownList checkDropDown "" pos:[5,315] width:140 height:20 enabled:false
		--checkbox checkSelector "" pos:[168,315] width:50 height:20 enabled:false
		button checkON "ON" pos:[150,317] width:25 height:15 enabled:false
		button checkOFF "OFF" pos:[175,317] width:25 height:15 enabled:false
		
		dropDownList colorDropDown "" pos:[5,345] width:140 height:20 enabled:false
		colorPicker colorSelector "" pos:[156,345] width:34 height:20 enabled:false
		
		dropDownList mapDropDown "" pos:[5,375] width:140 height:20 enabled:false
		mapButton mapSelector "M" pos:[160,375] width:30 height:20 enabled:false
		
		dropDownList mapAmtDropDown "" pos:[5,405] width:140 height:20 enabled:false
		spinner mapAmtSelector "" pos:[155,407] range:[0,100,100] type:#integer scale:1 width:45 height:16 enabled:false
		
		dropDownList mapCheckDropDown "" pos:[5,435] width:140 height:20 enabled:false
		--checkbox mapCheckSelector "" pos:[168,435] width:50 height:20 enabled:false
		button mapCheckON "ON" pos:[150,437] width:25 height:15 enabled:false
		button mapCheckOFF "OFF" pos:[175,437] width:25 height:15 enabled:false
		
		-------------------------------------------------------------------
		on brazil2Rollout open do
		(
			local lastSelection = ""
			
			local spinnerProperties = #("Ka","Kd","Kl","IOR","Kr","Reflection Glossiness","Reflection Samples","Reflection Error", \
										"Reflection Decay Start","Reflection Decay End","Reflection Decay Env","Refraction Glossiness", \
										"Refraction Samples","Refraction Error","Refraction Abs Red","Refraction Abs Green", \
										"Refraction Abs Blue","Refraction Abs Start","Refraction Abs End","Refraction IOR Var", \
										"Refraction Spectral Steps","Specular Level","Specular Glossiness","Specular Soften", \
										"Specular Gain","Anisotropy")
			
			local checkProperties = #("2-Sided","Face Map","Faceted","Transparent Shadows","Reflection Glossiness","Reflection Sampling", \
									  "Reflection Decay","Prevent Internal Reflect","Reflection Caustics","Refraction Glossiness", \
									  "Refraction Sampling","Refraction Absorption","Refraction Dispersion","Refraction Caustics", \
									  "Area Speculars","Use Opacity for Trans")
										
			local colorProperties = #("Ambient","Diffuse","Luminosity","Opacity","Reflection","Reflection Tint","Reflection Decay", \
									  "Refraction Absorption","Specular Color","Extra Light")
			
			local mapProperties = #("Reflection Glossiness","Refraction Glossiness","Refraction Absorption","Diffuse", \
									"Opacity","Extra Light","Diffusion","Bump","Displacement","Environment", \
								    "Ambient","Luminosity","Ka","Kd","Kl","Reflection","Reflection Tint", \
								    "Kr","IOR","Specular Color","Specular Level","Specular Glossiness", \
								    "Specular Soften","Specular Gain")
									
			local mapAmountProperties = #("Reflection Gloss Map","Refraction Gloss Map","Refraction Absorption Map","Diffuse Map", \
									      "Opacity Map","Extra Light Map","Diffusion Map","Bump Map","Displacement Map", \
									      "Ambient Map","Luminosity Map","Ka Map","Kd Map","Kl Map","Reflection Map","Reflection Tint Map", \
									      "Kr Map","IOR Map","Specular Color Map","Specular Level Map","Specular Gloss Map", \
									      "Specular Soften Map","Specular Gain Map")
									
			local mapCheckProperties = #("Reflect Gloss Map","Refract Gloss Map","Refract Absorb Map","Diffuse Map", \
										 "Opacity Map","Extra Light Map","Diffusion Map","Bump Map","Displacement Map","Environment Map", \
										 "Ambient Map","Luminosity Map","Ka Map","Kd Map","Kl Map","Reflect Map","Reflect Tint Map", \
										 "Kr Map","IOR Map","Specular Color Map","Specular Level Map","Specular Gloss Map", \
										 "Specular Soften Map","Specular Gain Map")
						
			spinnerDropDown.items = spinnerProperties
			checkDropDown.items = checkProperties
			colorDropDown.items = colorProperties
			mapDropDown.items = mapProperties
			mapAmtDropDown.items = mapAmountProperties
			mapCheckDropDown.items = mapCheckProperties
			
			lastSelection = getIniSetting brazil2IniFile "Spinner" "Selection"
			if lastSelection != "" do spinnerDropDown.selection = (lastSelection as integer)
			lastSelection = getIniSetting brazil2IniFile "Check" "Selection"
			if lastSelection != "" do checkDropDown.selection = (lastSelection as integer)
			lastSelection = getIniSetting brazil2IniFile "Color" "Selection"
			if lastSelection != "" do colorDropDown.selection = (lastSelection as integer)
			lastSelection = getIniSetting brazil2IniFile "Map" "Selection"
			if lastSelection != "" do mapDropDown.selection = (lastSelection as integer)
			lastSelection = getIniSetting brazil2IniFile "Map Amount" "Selection"
			if lastSelection != "" do mapAmtDropDown.selection = (lastSelection as integer)
			lastSelection = getIniSetting brazil2IniFile "Map Check" "Selection"
			if lastSelection != "" do mapCheckDropDown.selection = (lastSelection as integer)
			
			if (classOf Brazil2_Advanced_Material) == material then Refresh_Material_List()
			else messagebox "Brazil plugin not detected." title:"ERROR"
		)--end on
		
		-------------------------------------------------------------------
		on brazil2Rollout moved pos do
			setIniSetting brazil2IniFile "Dialog" "Position" (pos as string)
			
		-------------------------------------------------------------------
		on brazil2Rollout close do
		(
			setIniSetting brazil2IniFile "Spinner" "Selection" (spinnerDropDown.selection as string)
			setIniSetting brazil2IniFile "Check" "Selection" (checkDropDown.selection as string)
			setIniSetting brazil2IniFile "Color" "Selection" (colorDropDown.selection as string)
			setIniSetting brazil2IniFile "Map" "Selection" (mapDropDown.selection as string)
			setIniSetting brazil2IniFile "Map Amount" "Selection" (mapAmtDropDown.selection as string)
			setIniSetting brazil2IniFile "Map Check" "Selection" (mapCheckDropDown.selection as string)
		)--end on
		
		-------------------------------------------------------------------
		on updateButton pressed do
		(
			if (classOf Brazil2_Advanced_Material) == material then Refresh_Material_List()
			else messagebox "Brazil plugin not detected." title:"ERROR"
		)--end on
		
		-------------------------------------------------------------------
		on spinnerDropDown selected theIndex do
		(
			case theIndex of
			(
				(1):spinnerSelector.range = [0,100,1]
				(2):spinnerSelector.range = [0,100,1]
				(3):spinnerSelector.range = [0,100,1]
				(4):spinnerSelector.range = [0,100,1.5]
				(5):spinnerSelector.range = [0,100,1]
				(6):spinnerSelector.range = [1,100,80]
				(7):spinnerSelector.range = [1,32,10]
				(8):spinnerSelector.range = [0,1,0.01]
				(9):spinnerSelector.range = [0,999999,0]
				(10):spinnerSelector.range = [0,999999,100]
				(11):spinnerSelector.range = [0,100,1]
				(12):spinnerSelector.range = [1,100,80]
				(13):spinnerSelector.range = [1,32,10]
				(14):spinnerSelector.range = [0,1,0.01]
				(15):spinnerSelector.range = [0,100,1]
				(16):spinnerSelector.range = [0,100,1]
				(17):spinnerSelector.range = [0,100,1]
				(18):spinnerSelector.range = [0,999999,0]
				(19):spinnerSelector.range = [0,999999,100]
				(20):spinnerSelector.range = [0,100,0.1]
				(21):spinnerSelector.range = [3,81,6]
				(22):spinnerSelector.range = [0,1000,80]
				(23):spinnerSelector.range = [0,1000,50]
				(24):spinnerSelector.range = [0,1000,0.1]
				(25):spinnerSelector.range = [0,1,0.5]
				(26):spinnerSelector.range = [0,1,0]
				(27):spinnerSelector.range = [0,180,0]
			)--end case
		)--end on
		
		-------------------------------------------------------------------
		on mapAmtDropDown selected theIndex do
		(
			if theIndex == 8 or theIndex == 9 then
				mapAmtSelector.range = [-999,999,30]
			else
				mapAmtSelector.range = [0,100,100]
		)--end on
		
		-------------------------------------------------------------------
		on spinnerSelector changed theValue do Set_Material_Main theValue 1
		on checkON pressed do Set_Material_Main true 2
		on checkOFF pressed do Set_Material_Main false 2
		on colorSelector changed theColor do Set_Material_Main theColor 3
		on mapSelector picked theMap do Set_Material_Main theMap 4
		on mapAmtSelector changed theValue do Set_Material_Main theValue 5
		on mapCheckON changed theState do Set_Material_Main true 6
		on mapCheckOFF changed theState do Set_Material_Main false 6
	)--end rollout
	brazil2RolloutPos = execute (getIniSetting brazil2IniFile "Dialog" "Position")
	if brazil2RolloutPos == OK do brazil2RolloutPos = [100,100]
	if brazil2RolloutPos.x > sysinfo.desktopsize.x - 205 do brazil2RolloutPos.x = sysinfo.desktopsize.x - 210
	if brazil2RolloutPos.y > sysinfo.desktopsize.y - 520 do brazil2RolloutPos.y = sysinfo.desktopsize.y - 520
	if brazil2RolloutPos.x < 0 do brazil2RolloutPos.x = 0 
	if brazil2RolloutPos.y < 0 do brazil2RolloutPos.y = 0
	createDialog brazil2Rollout 205 460 brazil2RolloutPos.x brazil2RolloutPos.y style:#(#style_titlebar, #style_minimizebox, #style_border, #style_sysmenu)
)--end local scope